Learn R Programming

shinyMixR (version 0.5.3)

adpt_meta: Adapt meta information inside a nlmixr UIF

Description

regular expressions are used to search for meta data inside a model file. This meta data is then updated with the provided new values

Usage

adpt_meta(mdl, newvals)

Value

character vector with model including the adapted meta data

Arguments

mdl

character with the name of the model to adapt

newvals

list with characteristics/meta data to adapt

Author

Richard Hooijmaijers

Examples

Run this code

if (FALSE) {
  adpt_meta("model.r",newvals=list(imp=4,ref="run 1"))
}

Run the code above in your browser using DataLab