Learn R Programming

shinyMixR (version 0.5.3)

incr_mdl: Increments a model name

Description

A model name is incremented either by incrementing numerical or alpha numerical. Furthermore it is possible to check the existence of the incremented model and take this into account.

Usage

incr_mdl(mod, checkloc = NULL)

Value

character with the incremented name

Arguments

mod

character with the model name

checkloc

character with the location to check for existence of a file

Author

Richard Hooijmaijers

Examples

Run this code

 incr_mdl("run01.r")

Run the code above in your browser using DataLab