Learn R Programming

shinyMixR (version 0.5.3)

setup_shinymixr_test: Record a shinyMixR test

Description

Record a shinyMixR test

Usage

setup_shinymixr_test(
  dir = "./tests/files",
  overwrite = TRUE,
  record = FALSE,
  incres = FALSE
)

Value

runs the shinyMixR interface and records actions in the app

Arguments

dir

character, the directory where the files will be placed and the test will be recorded

overwrite

logical, if TRUE, the function will remove the content of the tests/files directory

record

logical, if TRUE, the function will use `record_test`

incres

logical, if TRUE, the function will include result files for testing