powered by
regular expressions are used to search for meta data inside a model file. This meta data is then updated with the provided new values
adpt_meta(mdl, newvals)
character vector with model including the adapted meta data
character with the name of the model to adapt
list with characteristics/meta data to adapt
Richard Hooijmaijers
if (FALSE) { adpt_meta("model.r",newvals=list(imp=4,ref="run 1")) }
Run the code above in your browser using DataLab