Record a shinyMixR test
setup_shinymixr_test(
dir = "./tests/files",
overwrite = TRUE,
record = FALSE,
incres = FALSE
)runs the shinyMixR interface and records actions in the app
character, the directory where the files will be placed and the test will be recorded
logical, if TRUE, the function will remove the content of the tests/files directory
logical, if TRUE, the function will use `record_test`
logical, if TRUE, the function will include result files for testing